<!-- markdownlint-disable -->

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/filter.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `filter`





---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/filter.py#L26"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `feature_filter`

```python
feature_filter(primary_data, filter_tuple=('power', 'line'))
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/filter.py#L39"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `run_feature_filter`

```python
run_feature_filter(primary_dict, feature_name)
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/filter.py#L62"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `run_primary_filter`

```python
run_primary_filter(PBF_inputfile, primary_file, primary_name, multiprocess)
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/filter.py#L96"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `get_filtered_data`

```python
get_filtered_data(region, primary_name, feature_name, mp, update, data_dir)
```






